// STRATEGY API
import HTTP, {getErrorObj, queryParamsStringfy} from "./http-fetch";

async function getStrategies(groupId, search) {
    const response = await HTTP.getData('/users/strategies/'+queryParamsStringfy({groupId, search}))
    if (response.ok) {
        const strategiesJson = await response.json();
        return strategiesJson.map(strategy => ({...strategy, id: strategy._id}));
    } else {
        throw getErrorObj(response, 'Error on load user strategies');
    }
}

async function getStrategy(id) {
    const response = await HTTP.getData('/users/strategies/'+id+'/')
    if (response.ok) {
        const strategyJson = await response.json();
        return {...strategyJson, id: strategyJson._id};
    } else {
        throw getErrorObj(response, 'Error on load user strategy');
    }
}

async function getStrategyProfit(id) {
    const response = await HTTP.getData('/users/strategies/'+ id +'/profit/')
    if (response.ok) {
        const profitJson = await response.json();
        return profitJson;
    } else {
        throw getErrorObj(response, 'Error on load user strategy profit');
    }
}

async function getStrategyGreeks(id) {
    const response = await HTTP.getData('/users/strategies/'+ id +'/greeks/')
    if (response.ok) {
        const profitJson = await response.json();
        return profitJson;
    } else {
        throw getErrorObj(response, 'Error on load user strategy profit');
    }
}

async function createStrategy(groupId, name) {
    return HTTP.postData('/users/strategies/', {groupId, name});
}

async function updateStrategy(id, name, orders, whatif, disabled=undefined) {
    return HTTP.postData('/users/strategies/'+ id + '/', {name, orders, whatif, disabled});
}

async function deleteStrategy(id) {
    return HTTP.deleteData('/users/strategies/'+ id + '/');
}

const StrategyAPI = { 
    getStrategies, 
    getStrategy, getStrategyProfit, getStrategyGreeks, 
    createStrategy, updateStrategy, deleteStrategy,
};

export default StrategyAPI;
