import React, { useEffect } from "react";
import { connect } from "react-redux";
import { Form } from "react-bootstrap";
import { SiAddthis } from "react-icons/si";

import BaseListGroup from "../../../commons/components/list-groups/BaseListGroup";
import ButtonIcon from "../../../commons/components/buttons/button-icon/ButtonIcon";

import { LoadStrategies, ToggleStrategyCard } from "../../../state/strategy/strategy.action";
import { OpenModal } from "../../../state/modal/modal.action";

import { ModalCatalog } from "../../../enums/modal-catalog.enum";

import "./StrategySearch.css";


function ConnectedStrategySearch({search, results, cards, groups, wait, dispatch}) {
    useEffect(()=> dispatch(LoadStrategies(search)), []);

    return (
        <div className="app-strategy-search">
            <Form className="app-strategy-search--form">
                <Form.Group controlId="searchForm">
                    <Form.Control
                        type="text"
                        value={search || ""}
                        placeholder="Search"
                        onChange={(event) => dispatch(LoadStrategies(event.target.value))}
                    />
                </Form.Group>
            </Form>
            <div className="app-strategy-search--add">
                <ButtonIcon 
                    theme="dark"
                    fontSize={20}
                    onClick={() => dispatch(OpenModal(ModalCatalog.CreateStrategy(groups)))}
                >
                    <SiAddthis/>
                </ButtonIcon>
            </div>
            <div className="app-strategy-search--result">
                <BaseListGroup
                    items={results
                        .sort((a,b) => b.name-a.name)
                        .map(result => ({
                            key: result.id,
                            label: result.name,
                            selected: result.id in cards,
                            disabled: wait != 0,
                            onSelect: (selected) => dispatch(ToggleStrategyCard(result, selected))
                        }))
                    }
                >
                </BaseListGroup>
            </div>

        </div>
    );
};

const mapStateToProps = ({ strategies, app }) => {
    return {...strategies, groups: app.groups, wait: app.wait };
}

const mapDispatchToProps = dispatch => {
    return {
        dispatch: (action) => {dispatch(action)},
    };
}


const StrategySearch = connect(mapStateToProps, mapDispatchToProps)(ConnectedStrategySearch)

export default StrategySearch;
