import API from "../../../api/api";
import { StrategyChartCatalog as ChartCatalog } from "../../enums/chart-catalog.enum";

import { HandleAppError, SetAppLoader } from "../app.action";
import StrategyAction, 
{ LoadStrategies, LoadStrategiesFailed, LoadStrategiesSuccess, LoadStrategy,
LoadStrategyChart, LoadStrategyChartFailed, LoadStrategyChartSuccess, LoadStrategyFailed, LoadStrategySuccess } from "./strategy.action";


export function strategiesEffect(action, dispatch) {

    switch (action.type) {
    
        case StrategyAction.Type.LoadStrategies:
            dispatch(SetAppLoader(true))
            API.getStrategies(null, action.search)
                .then((strategies) => {
                    dispatch(LoadStrategiesSuccess(strategies));
                })
                .catch((err) => {
                    dispatch(LoadStrategiesFailed());
                    dispatch(HandleAppError(err));
                })
                .finally(() => dispatch(SetAppLoader(false)));
            break;

        case StrategyAction.Type.LoadStrategy:
            API.getStrategy(action.id)
            .then((strategy)=> {
                dispatch(LoadStrategySuccess(strategy, []));
                dispatch(LoadStrategyChart(action.id, 0))
            })
            .catch((err) => {
                dispatch(LoadStrategyFailed(action.id));
                dispatch(HandleAppError(err));
            });
            break;

        case StrategyAction.Type.CreateStrategy:
            API.createStrategy(action.groupId, action.name)
            .then(() => dispatch(LoadStrategies()))
            .catch((err) => dispatch(HandleAppError(err)));
            break;

        case StrategyAction.Type.UpdateStrategy:
            API.updateStrategy(action.id, null, action.orders, action.whatif)
            .then(() => dispatch(LoadStrategy(action.id)))
            .catch((err) => dispatch(HandleAppError(err)));
            break;
        
        case StrategyAction.Type.LoadStrategyChart:
            var chart = action.chartId < ChartCatalog.length ? ChartCatalog[action.chartId] : ChartCatalog[0];
            var params = {strategyId: action.id, chartId: action.chartId};
            if (chart && chart.checkRequisits(params)) {
                API.getChart(chart, params)
                    .then((data) => {
                        dispatch(LoadStrategyChartSuccess(action.id, chart, chart.getData(data)));
                    })
                    .catch((err) => {
                        dispatch(LoadStrategyChartFailed(action.id));
                        dispatch(HandleAppError(err));
                    });
            } else {
                setTimeout(() => {
                    dispatch(LoadStrategyChartSuccess(chart, {params:{}, items: []}));
                }, 300);
            }
            
            break;

        default:
            break;
    }
}
