import { StrategyChartCatalog as ChartCatalog} from "../../enums/chart-catalog.enum";
import { ChartState, LoadingState, SearchState } from "../app.reducer";
import StrategyAction from "./strategy.action";

const StrategyState = {
    ...LoadingState,
    chart: {...ChartState, full: false},
    full: false,
    open: true,
    markets: [],
    positions: [],
    stats: {
        original: {}
    },
}

const StrategiesState = {
    ...LoadingState,
    ...SearchState,
    open: true,
    cards: {},
    charts: ChartCatalog,
};

export function strategiesReducer(state = StrategiesState, action) {

    switch (action.type) {

        case StrategyAction.Type.LoadStrategies:
            return {...state, search: action.search, loading: true, failed: false}

        case StrategyAction.Type.LoadStrategiesSuccess:
            return {...state, results: action.results, loading: false};

        case StrategyAction.Type.LoadStrategiesFailed:
            return {...state, loading: false, failed: true};

         // Card
         case StrategyAction.Type.ToggleStrategyCard:
            if (!action.active) {
                state.cards[action.card.id] = {...StrategyState, ...action.card};
            } else {
                delete state.cards[action.card.id];
            }
            return {...state, cards: {...state.cards}};


        case StrategyAction.Type.UpdateStrategyCard:
            if (action.card.id in state.cards) {
                var card = state.cards[action.card.id];
                state.cards[action.card.id] = {...card, ...action.card};
            }
            return {...state, cards: {...state.cards}};
        
        // Strategy

        case StrategyAction.Type.LoadStrategy:
            if (action.id in state.cards) {
                var card = state.cards[action.id];
                state.cards[action.id] = {...card, loading: true, failed: false};
            }
            return {...state, cards: {...state.cards}};

        case StrategyAction.Type.LoadStrategySuccess:
            if (action.strategy.id in state.cards) {
                var strategy = state.cards[action.strategy.id];
                state.cards[action.strategy.id] = {...strategy, ...action.strategy, profits: action.profits, loading: false};
            }
            return {...state, cards: {...state.cards}};

        case StrategyAction.Type.LoadStrategyFailed:
            if (action.id in state.cards) {
                var card = state.cards[action.id];
                state.cards[action.id] = {...card, loading: false, failed: true};
            }
            return {...state, cards: {...state.cards}};


        // CHART:
        case StrategyAction.Type.ToggleStrategyChart:
            if (action.id in state.cards) {
                var card = state.cards[action.id];
                state.cards[action.id] = {...card, chart: {...card.chart, open: !card.chart.open, full: !card.chart.full}};
            }
            return {...state, cards: {...state.cards}};

        case StrategyAction.Type.LoadStrategyChart: 
            if (action.id in state.cards) {
                var card = state.cards[action.id];
                state.cards[action.id] = {...card, chart: {...card.chart, loading: true, failed: false}};
            }
            return {...state, cards: {...state.cards}};

        case StrategyAction.Type.LoadStrategyChartSuccess:
            if (action.id in state.cards) {
                var card = state.cards[action.id];
                state.cards[action.id] = {...card, chart: {...card.chart, ...action.chart, ...action.data, loading: false}};
            }
            return {...state, cards: {...state.cards}};

        case StrategyAction.Type.LoadStrategyChartFailed:
            if (action.id in state.cards) {
                var card = state.cards[action.id];
                state.cards[action.id] = {...card, chart: {...card.chart, items: [], params: {}, loading: false, failed: true}};
            }
            return {...state, cards: {...state.cards}};
                
        default:
            return {...state, cards: {...state.cards}};
    }
}
